Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: cc/test/ordered_simple_task_runner.h

Issue 935333002: Update from https://crrev.com/316786 (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/test/layer_tree_pixel_test.cc ('k') | cc/test/ordered_simple_task_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/test/ordered_simple_task_runner.h
diff --git a/cc/test/ordered_simple_task_runner.h b/cc/test/ordered_simple_task_runner.h
index b6e03ba50bc237f1f7fb5fca4004d38480100e62..54b1db4b6f9a0632dafe01bebb99d4b07b23edcf 100644
--- a/cc/test/ordered_simple_task_runner.h
+++ b/cc/test/ordered_simple_task_runner.h
@@ -34,9 +34,9 @@ class TestOrderablePendingTask : public base::TestPendingTask {
bool operator==(const TestOrderablePendingTask& other) const;
bool operator<(const TestOrderablePendingTask& other) const;
- // debug tracing functions
- scoped_refptr<base::debug::ConvertableToTraceFormat> AsValue() const;
- void AsValueInto(base::debug::TracedValue* state) const;
+ // base::trace_event tracing functionality
+ scoped_refptr<base::trace_event::ConvertableToTraceFormat> AsValue() const;
+ void AsValueInto(base::trace_event::TracedValue* state) const;
private:
static size_t task_id_counter;
@@ -102,9 +102,9 @@ class OrderedSimpleTaskRunner : public base::SingleThreadTaskRunner {
bool RunUntilTime(base::TimeTicks time);
bool RunForPeriod(base::TimeDelta period);
- // base::debug tracing functionality
- scoped_refptr<base::debug::ConvertableToTraceFormat> AsValue() const;
- virtual void AsValueInto(base::debug::TracedValue* state) const;
+ // base::trace_event tracing functionality
+ scoped_refptr<base::trace_event::ConvertableToTraceFormat> AsValue() const;
+ virtual void AsValueInto(base::trace_event::TracedValue* state) const;
// Common conditions to run for, exposed publicly to allow external users to
// use their own combinations.
« no previous file with comments | « cc/test/layer_tree_pixel_test.cc ('k') | cc/test/ordered_simple_task_runner.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698